@@ -2,15 +2,13 @@
 
 import glob
 import os.path
+import pathlib
 import platform
 import sys
 import sysconfig
 
 from cx_Freeze import Executable, setup
 
-import meld.build_helpers
-import meld.conf
-
 
 def get_non_python_libs():
     """Returns list of tuples containing extra dependencies required to run
@@ -29,7 +27,7 @@ def get_non_python_libs():
 
     if 'mingw' in sysconfig.get_platform():
         # dll imported by dll dependencies expected to be auto-resolved later
-        inst_root = [os.path.join(local_bin, 'libgtksourceview-3.0-1.dll')]
+        inst_root = [os.path.join(local_bin, 'libgtksourceview-4-0.dll')]
 
         # required for communicating multiple instances
         inst_lib.append(os.path.join(local_bin, 'gdbus.exe'))
@@ -54,7 +52,7 @@ gtk_data_dirs = [
     'lib/girepository-1.0',
     'share/fontconfig',
     'share/glib-2.0',
-    'share/gtksourceview-3.0',
+    'share/gtksourceview-4',
     'share/icons',
 ]
 
@@ -95,15 +93,15 @@ build_exe_options = {
 
 # Create our registry key, and fill with install directory and exe
 registry_table = [
-    ('MeldKLM', 2, 'SOFTWARE\Meld', '*', None, 'TARGETDIR'),
-    ('MeldInstallDir', 2, 'SOFTWARE\Meld', 'InstallDir', '[TARGETDIR]', 'TARGETDIR'),
-    ('MeldExecutable', 2, 'SOFTWARE\Meld', 'Executable', '[TARGETDIR]Meld.exe', 'TARGETDIR'),
+    ('MeldKLM', 2, r'SOFTWARE\Meld', '*', None, 'TARGETDIR'),
+    ('MeldInstallDir', 2, r'SOFTWARE\Meld', 'InstallDir', '[TARGETDIR]', 'TARGETDIR'),
+    ('MeldExecutable', 2, r'SOFTWARE\Meld', 'Executable', '[TARGETDIR]Meld.exe', 'TARGETDIR'),
 ]
 
 # Provide the locator and app search to give MSI the existing install directory
 # for future upgrades
 reg_locator_table = [
-    ('MeldInstallDirLocate', 2, 'SOFTWARE\Meld', 'InstallDir', 0)
+    ('MeldInstallDirLocate', 2, r'SOFTWARE\Meld', 'InstallDir', 0)
 ]
 app_search_table = [('TARGETDIR', 'MeldInstallDirLocate')]
 
@@ -116,8 +114,6 @@ msi_data = {
 bdist_msi_options = {
     "upgrade_code": "{1d303789-b4e2-4d6e-9515-c301e155cd50}",
     "data": msi_data,
-    "all_users": True,
-    "install_icon": "data/icons/org.gnome.meld.ico",
 }
 
 executable_options = {
@@ -127,12 +123,24 @@ executable_options = {
 
 if 'mingw' in sysconfig.get_platform():
     executable_options.update({
-         "base": "Win32GUI",  # comment to build cosole version to see stderr
+         "base": "Win32GUI",  # comment to build console version to see stderr
          "targetName": "Meld.exe",
          "shortcutName": "Meld",
          "shortcutDir": "ProgramMenuFolder",
     })
 
+# Copy conf.py in place if necessary
+base_path = pathlib.Path(__file__).parent
+conf_path = base_path / 'meld' / 'conf.py'
+
+if not conf_path.exists():
+    import shutil
+    shutil.copyfile(conf_path.with_suffix('.py.in'), conf_path)
+
+import meld.build_helpers  # noqa: E402
+import meld.conf  # noqa: E402
+
+
 setup(
     name="Meld",
     version=meld.conf.__version__,
@@ -141,6 +149,7 @@ setup(
     author_email='meld-list@gnome.org',
     maintainer='Kai Willadsen',
     url='http://meldmerge.org',
+    license='GPLv2+',
     classifiers=[
         'Development Status :: 5 - Production/Stable',
         'Environment :: X11 Applications :: GTK',
@@ -148,10 +157,12 @@ setup(
         'Intended Audience :: System Administrators',
         'License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)',
         'Programming Language :: Python',
+        'Programming Language :: Python :: 3 :: Only',
         'Topic :: Desktop Environment :: Gnome',
         'Topic :: Software Development',
         'Topic :: Software Development :: Version Control',
     ],
+    keywords=['diff', 'merge'],
     options={
         "build_exe": build_exe_options,
         "bdist_msi": bdist_msi_options,
@@ -170,19 +181,17 @@ setup(
         'meld.vc',
     ],
     package_data={
-        'meld': ['README', 'COPYING', 'NEWS']
+        'meld': ['README', 'COPYING', 'NEWS'],
+        'meld.vc': ['README', 'COPYING'],
     },
     scripts=['bin/meld'],
     data_files=[
         ('share/man/man1',
-         ['meld.1']
+         ['data/meld.1']
          ),
         ('share/doc/meld-' + meld.conf.__version__,
          ['COPYING', 'NEWS']
          ),
-        ('share/meld',
-         ['data/meld.css']
-         ),
         ('share/meld/icons',
          glob.glob("data/icons/*.png") +
          glob.glob("data/icons/COPYING*")
